@@ -14,7 +14,9 @@ from requests.models import Request
 from localstack import config
 from localstack.config import ServiceProviderConfig
 from localstack.utils.bootstrap import get_enabled_apis, is_api_enabled, log_duration
-from localstack.utils.common import call_safe, poll_condition, wait_for_port_status
+from localstack.utils.functions import call_safe
+from localstack.utils.net import wait_for_port_status
+from localstack.utils.sync import poll_condition
 
 # set up logger
 LOG = logging.getLogger(__name__)
@@ -218,7 +220,7 @@ class ServiceContainer:
         self.service = service
         self.state = state
         self.lock = threading.RLock()
-        self.errors = list()
+        self.errors = []
 
     def get(self) -> Service:
         return self.service
@@ -258,7 +260,7 @@ class ServiceContainer:
 class ServiceManager:
     def __init__(self) -> None:
         super().__init__()
-        self._services = dict()
+        self._services = {}
         self._mutex = threading.RLock()
 
     def get_service_container(self, name: str) -> Optional[ServiceContainer]:
@@ -288,7 +290,7 @@ class ServiceManager:
             return self.get_service_container(name).check()
 
     def check_all(self):
-        return any([self.check(service_name) for service_name in self.list_available()])
+        return any(self.check(service_name) for service_name in self.list_available())
 
     def get_state(self, name: str) -> Optional[ServiceState]:
         container = self.get_service_container(name)
@@ -313,6 +315,10 @@ class ServiceManager:
             if not poll_condition(lambda: container.state != ServiceState.STARTING, timeout=30):
                 raise TimeoutError("gave up waiting for service %s to start" % name)
 
+        if container.state == ServiceState.STOPPING:
+            if not poll_condition(lambda: container.state == ServiceState.STOPPED, timeout=30):
+                raise TimeoutError("gave up waiting for service %s to stop" % name)
+
         with container.lock:
             if container.state == ServiceState.DISABLED:
                 raise ServiceDisabled("service %s is disabled" % name)
@@ -324,7 +330,7 @@ class ServiceManager:
                 # raise any capture error
                 raise container.errors[-1]
 
-            if container.state == ServiceState.AVAILABLE:
+            if container.state == ServiceState.AVAILABLE or container.state == ServiceState.STOPPED:
                 if container.start():
                     return container.service
                 else:
@@ -419,7 +425,7 @@ class ServicePluginErrorCollector(PluginLifecycleListener):
 
     def __init__(self, errors: Dict[str, Exception] = None) -> None:
         super().__init__()
-        self.errors = errors or dict()
+        self.errors = errors or {}
 
     def get_key(self, plugin_name) -> Tuple[str, str]:
         # the convention is <api>:<provider>, currently we don't really expose the provider
@@ -513,7 +519,7 @@ class ServicePluginManager(ServiceManager):
             return None
 
         with self._mutex:
-            if plugin.service not in self._services:
+            if plugin.service.name() not in self._services:
                 super().add_service(plugin.service)
 
         return super().get_service_container(name)
@@ -575,7 +581,7 @@ class ServicePluginManager(ServiceManager):
         :param provider: Name of the provider
         :return: List of apis the given provider provides
         """
-        apis = list()
+        apis = []
         for api, providers in self.api_provider_specs.items():
             if provider in providers:
                 apis.append(api)
